<?php
/**
 * @file
 * Provides administration functions for the auto_retina module.
 *
 * @ingroup auto_retina
 * @{
 */

/**
 * Form builder. Configure settings for auto_retina.
 *
 * @ingroup forms
 * @see system_settings_form()
 */
function auto_retina_admin_settings($form, &$form_state) {

  $form['auto_retina_suffix'] = array(
    '#type' => 'textfield',
    '#title' => t('Retina filename suffix'),
    '#description' => t('This suffix appears at the end of a filename, before the dot+extension to indicate it is the retina version of an image.'),
    '#default_value' => variable_get('auto_retina_suffix', AUTO_RETINA_SUFFIX),
    '#required' => TRUE,
  );

  if (module_exists('image_style_quality')) {
    $form['auto_retina_quality_multiplier'] = array(
      '#title'         => t('JPEG Quality Multiplier (for Retina images only)'),
      '#type'          => 'textfield',
      '#field_suffix'  => 'x JPEG percentage',
      '#size'          => 4,

      '#description'   => t('Use this to alter or reduce the JPEG quality used when generating the retina image.  If a given style includes an image style quality effect it will be used as the basis, if not then the <a href="!url">image toolkit default</a> is used. <strong>If the basis is 80% and you leave this at 1, the retina image will be generated at 80% (no change); however if you set this to .5 then the retina image will be generated at 40%.</strong>  The lower the number above, the smaller will be the file size of the retina image, <em>at the expense of quality</em>.', array('!url' => url('admin/config/media/image-toolkit', array('query' => drupal_get_destination())))),
      '#default_value' => variable_get('auto_retina_quality_multiplier', 1),
    );
  }
  else {
    $form['name'] = array(
      '#markup' => t('<p>We suggest installing the <a href="!url">Image style quality module</a> for more options.</p>', array('!url' => url('https://www.drupal.org/project/image_style_quality'))),
    );
  }

  $form['advanced'] = array(
    '#type' => 'fieldset',
    '#title' => t('Advanced'),
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
  );

  $form['advanced']['auto_retina_regex'] = array(
    '#type' => 'textfield',
    '#title' => t('Retina filename regex'),
    '#description' => t('Enter a regex expression to use for determining if an url is retina.  The token <code>[suffix]</code> may be used to dynamically populate the setting from above. You may omit start/end delimiters.'),
    '#default_value' => variable_get('auto_retina_regex', AUTO_RETINA_REGEX),
    '#required' => TRUE,
  );

  $form['advanced']['auto_retina_js'] = array(
    '#type' => 'checkbox',
    '#title' => t('Include the javascript settings <code>Drupal.settings.autoRetina</code> on every page?'),
    '#default_value' => variable_get('auto_retina_js', AUTO_RETINA_JS),
  );

  return system_settings_form($form);
}
