<?php

/**
 * @file
 * PHPUnit tests for the AutoRetina class
 */

require_once dirname(__FILE__) . '/../../auto_retina.module';

function variable_get($name, $default) {
  return $default;
}

class AutoRetinaTest extends \PHPUnit_Framework_TestCase {

  /**
   * Provides data for testImageStyleAddRetinaSettings.
   */
  function DataForTestImageStyleAddRetinaSettingsProvider() {
    $tests = array();

    $tests[] = array(
      'photo@2x.jpg',
      'photo.jpg',
      array('suffix' => '@2x', 'multiplier' => 2, 'quality_multiplier' => 1),
    );

    $tests[] = array(
      'photo.jpg',
      'photo.jpg',
      array('suffix' => '', 'multiplier' => 1, 'quality_multiplier' => 1),
    );

    return $tests;
  }

  /**
   * @dataProvider DataForTestImageStyleAddRetinaSettingsProvider
   */
  public function testImageStyleAddRetinaSettings($uri_in, $uri_out, $style_out) {
    $style = array();
    $uri = $uri_in;
    $original_url = auto_retina_image_style_prepare($style, $uri);
    $this->assertSame($uri_in, $uri);
    $this->assertSame($uri_out, $original_url);
    $this->assertSame(array('auto_retina' => $style_out), $style);
  }

  /**
   * Provides data for testBuildRetinaPath.
   */
  function DataForTestBuildRetinaPathProvider() {
    $tests = array();

    $tests[] = array(
      '/do/re/mi/photo.jpg', '/do/re/mi/photo@2x.jpg',
    );
    $tests[] = array(
      'photo.jpg', 'photo@2x.jpg',
    );
    $tests[] = array(
      'photo@2x.jpg', 'photo@2x.jpg',
    );

    return $tests;
  }

  /**
   * @dataProvider DataForTestBuildRetinaPathProvider
   */
  public function testBuildRetinaPath($subject, $control) {
    return $this->assertSame($control, auto_retina_get_retina_path($subject));
  }
}

